@@ -1,9 +1,9 @@
 #' Colourised IBD plot
 #'
-#' This is a pedagogical tools for illustrating the concept of
+#' This is a pedagogical tool for illustrating the concept of
 #' identity-by-descent, by representing the alleles in a pedigree by coloured
 #' points or letters. By default, the alleles are placed below each pedigree
-#' symbols, but any positions are possible, including inside. (See examples.)
+#' symbol, but this may be modified. (See examples.)
 #'
 #' @param x A `ped` object.
 #' @param alleles A list of length `pedsize(x)`. Each element should consist of
@@ -17,19 +17,17 @@
 #'   `alleles`.
 #' @param cex An expansion factor for the allele points/letters. Default: 3 for
 #'   points and 2 for text.
-#' @param sep The separation between haplotypes within a pair, given as a
-#'   multiple of the width of a pedigree symbol. Default: 0.5 when `pos = 0` and
-#'   1 otherwise.
+#' @param sep The separation between alleles within a pair, given as a multiple
+#'   of the width of a pedigree symbol. Default is 1 when `pos > 0` and 0.5 for
+#'   `pos = 0`.
 #' @param dist The distance between pedigree symbols and the alleles, given as a
-#'   multiple of the height of a pedigree symbol. Default: 1. Ignored when `pos
-#'   = 0`.
+#'   multiple of symbol size. Default: 1. Ignored when `pos = 0`.
 #' @param labs A logical indicating if labels should be included.
 #' @param checkFounders A logical. If TRUE (default), a warning is issued if a
 #'   founder has two equal alleles other than 0.
 #' @param checkParents A logical. If TRUE (default), a warning is issued if
 #'   someone's alleles don't match those of the parents. This a superficial test
 #'   and does not catch all Mendelian errors.
-#' @param margin Plot margins (bottom, left, top, right).
 #' @param ... Further arguments passed on to `plot.ped()`.
 #'
 #' @return The plot structure is returned invisibly.
@@ -56,16 +54,15 @@
 #' # Inside the pedigree symbols
 #' ibdDraw(x, als, cols = cols, pos = 0, symbolsize = 2.5)
 #'
-#' # Other placements (margins depend on device - may need adjustment)
-#' ibdDraw(x, als, cols = cols, pos = c(2, 4, 1, 1),
-#'         margin = c(2, 6, 2, 6))
+#' # Other placements
+#' ibdDraw(x, als, cols = cols, pos = c(2, 3, 1, 4))
 #'
 #' # Letters instead of points
-#' ibdDraw(x, als, cols = cols, symbol = "text", cex = 2)
+#' ibdDraw(x, als, cols = cols, symbol = "text")
 #'
 #' # Further arguments (note that `col` is an argument of `ped.plot()`)
-#' ibdDraw(x, als, cols = cols, pos = 0, symbolsize = 2,
-#'         labs = TRUE, hatched = 3:4, col = "blue")
+#' ibdDraw(x, als, cols = cols, pos = 0, symbolsize = 2.5,
+#'         labs = TRUE, fill = "lightgray")
 #'
 #' # Mutations are warned about (unless `checkParents = FALSE`)
 #' ibdDraw(x, alleles = list(1:2, 3:4, 5, 6))
@@ -75,7 +72,7 @@
 #' # Example 2: Cousin pedigree #
 #' ##############################
 #'
-#' x = swapSex(cousinPed(1), 3)
+#' x = cousinPed(1) |> swapSex(3) |> relabel()
 #' als = list(1:2, 3:4, NULL, c(1,3), c(2,3), NULL, 3, 3)
 #'
 #' cols = c(7, 3, 2, 4)
@@ -103,18 +100,18 @@
 #' #################################
 #'
 #' x = linearPed(2, sex = 2)
-#' als = list(1, 2, 2, 3, 2)
+#' als = list(1, 2, 3, 2, 2)
 #' ibdDraw(x, als, cols = 2:4)
 #'
 #'
 #' # Restore graphics parameters
 #' par(op)
 #'
-#' @importFrom graphics points text
+#' @importFrom graphics points text strheight strwidth
 #' @export
 ibdDraw = function(x, alleles, symbol = c("point", "text"), pos = 1, cols = NULL,
-                   cex = NA, sep = NULL, dist = 1, labs = FALSE, checkFounders = TRUE,
-                   checkParents = TRUE, margin = c(1, 1, 1, 1), ...) {
+                   cex = NA, sep = 1, dist = 1, labs = FALSE, checkFounders = TRUE,
+                   checkParents = TRUE, ...) {
 
   if(!is.ped(x))
     stop2("Argument `x` must be a `ped` object")
@@ -137,7 +134,6 @@ ibdDraw = function(x, alleles, symbol = c("point", "text"), pos = 1, cols = NULL
     stop2("Consecutive numbers should be used as alleles. Missing: ",
           setdiff(1:max(uniqAls), uniqAls))
 
-
   symbol = match.arg(symbol)
 
   if(is.na(cex))
@@ -149,12 +145,10 @@ ibdDraw = function(x, alleles, symbol = c("point", "text"), pos = 1, cols = NULL
   else if(length(cols) < max(uniqAls))
     stop2("Too few colours")
 
-  # Position and separation
+  # Position
+  if(!all(pos %in% 0:4))
+    stop2("Illegal `pos` value: ", setdiff(pos, 0:4))
   pos = rep(pos, length.out = nInd)
-  if(is.null(sep))
-    sep = ifelse(pos == 0, 0.5, 1)
-  else
-    sep = rep(sep, length.out = nInd)
 
   # ID labels?
   if(isTRUE(labs))
@@ -162,19 +156,47 @@ ibdDraw = function(x, alleles, symbol = c("point", "text"), pos = 1, cols = NULL
   else if(isFALSE(labs))
     labs = NULL
 
+  # Alignment
+  align = .pedAlignment(x, ...)
+
+  # Add extra space to fit alleles
+  addSpace = c(0,0,0,0)
+  boxapprox = strwidth("ABC", "inches", cex = 1) * 2.5/3
+  alleleH = strheight("M", "inches", cex = switch(symbol, point = cex*2/3, text = cex))
+
+  botid = align$plotord[align$yall == align$yrange[2]]
+  if(any(pos[botid] == 1))
+    addSpace[1] = dist*boxapprox + alleleH/2
+
+  topid = align$plotord[align$yall == align$yrange[1]]
+  if(any(pos[topid] == 3))
+    addSpace[3] = dist*boxapprox + alleleH/2
+
+  leftid = align$plotord[align$xall == align$xrange[1]]
+  if(any(pos[leftid] == 2))
+    addSpace[2] = boxapprox*(dist+sep) + alleleH/2
+  else if(any(pos[leftid] %in% c(1,3)))
+    addSpace[2] = max(0, alleleH/2 - (1-sep)*boxapprox/2)
+
+  rightid = align$plotord[align$xall == align$xrange[2]]
+  print(pos[rightid])
+  if(any(pos[rightid] == 4))
+    addSpace[4] = boxapprox*(dist+sep) + alleleH/2
+  else if(any(pos[rightid] %in% c(1,3)))
+    addSpace[4] = max(0, alleleH/2 - (1-sep)*boxapprox/2)
+
   # Underlying pedigree plot
-  p = plot(x, labs = labs, keep.par = TRUE, margin = margin, ...)
+  p = plot(x, labs = labs, keep.par = TRUE, addSpace = addSpace, ...)
 
   # Height/width of ped symbols
-  symh = p$boxh
-  symw = p$boxw
-  SEP = sep * symw
-  DIST = dist * symh
+  symh = p$scaling$boxh
+  symw = p$scaling$boxw
 
   fou = founders(x, internal = TRUE)
 
   # Loop through all individuals in pedigree
   for(i in 1:nInd) {
+
     als = alleles[[i]]
     if(is.null(als))
       next
@@ -198,6 +220,8 @@ ibdDraw = function(x, alleles, symbol = c("point", "text"), pos = 1, cols = NULL
                 setdiff(als, c(0, fa, mo)), call. = FALSE)
     }
 
+    SEP = if(pos[i] > 0) sep*symw else sep*symw/2
+
     # Centre of allele pair
     if(pos[i] == 0) {
       X = p$x[i]
@@ -205,24 +229,24 @@ ibdDraw = function(x, alleles, symbol = c("point", "text"), pos = 1, cols = NULL
     }
     if(pos[i] == 1) {
       X = p$x[i]
-      Y = p$y[i] + symh + DIST
+      Y = p$y[i] + symh + dist*symh
     }
     else if(pos[i] == 2) {
-      X = p$x[i] - symw/2 - DIST - SEP[i]/2
+      X = p$x[i] - symw/2 - dist*symw - SEP/2
       Y = p$y[i] + symh/2
     }
     else if(pos[i] == 3) {
       X = p$x[i]
-      Y = p$y[i] - DIST
+      Y = p$y[i] - dist*symh
     }
     else if(pos[i] == 4) {
-      X = p$x[i] + symw/2 + DIST + SEP[i]/2
+      X = p$x[i] + symw/2 + dist*symw + SEP/2
       Y = p$y[i] + symh/2
     }
 
     # Coordinates of pair
     if(length(als) == 2) {
-      X = c(X - SEP[i]/2, X + SEP[i]/2)
+      X = c(X - SEP/2, X + SEP/2)
       Y = c(Y,Y)
     }
 
@@ -240,5 +264,3 @@ ibdDraw = function(x, alleles, symbol = c("point", "text"), pos = 1, cols = NULL
 
   invisible(p)
 }
-
-#' ibdDraw(nuclearPed(), al = list(1:2, 3:4, c(1,3)), cols = c(3,7))
